package com.jdc.jdcproject.controller;

import com.jdc.jdcproject.entity.Equipment;
import com.jdc.jdcproject.service.EquipmentService;
import com.jdc.jdcproject.utils.Result;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/equipmentController")
public class EquipmentController {
    @Autowired
    private EquipmentService equipmentService;

    @Operation(summary = "查询所有设备")
    @GetMapping("findAllEquipment")
    public Result findAllEquipment() {
        List<Equipment> equipment = equipmentService.list();
        return Result.successResult().data("equipment", equipment);
    }

    @Operation(summary = "根据id查询设备信息")
    @GetMapping("findEquipmentById/{id}")
    public Result findEquipmentById(@PathVariable String id) {
        Equipment equipment = equipmentService.getById(id);
        return Result.successResult().data("equipment", equipment);
    }


    @Operation(summary = "修改设备信息")
    @PostMapping("updateEquipment")
    public Result updateEquipment(@RequestBody Equipment equipment) {
        boolean updateflag = equipmentService.updateById(equipment);
        if (updateflag) {
            return Result.successResult();
        } else {
            return Result.errorResult();
        }
    }

    @Operation(summary = "删除设备信息")
    @DeleteMapping("deleteEquipment/{id}")
    public Result deleteEquipment(@PathVariable String id) {
        boolean updateflag = equipmentService.removeById(id);
        if (updateflag) {
            return Result.successResult();
        } else {
            return Result.errorResult();
        }
    }

    @Operation(summary = "新增设备信息")
    @PostMapping("addEquipment")
    public Result addEquipment(@RequestBody Equipment equipment) {
        System.out.println(equipment);

        boolean updateflag = equipmentService.save(equipment);
        if (updateflag) {
            return Result.successResult();
        } else {
            return Result.errorResult();
        }
    }
}
